import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * De bal van het spel is een Minion. Het springt in het rond en stuitert tegen de muren en een aantal andere objecten in de wereld.
 * 
 * @author Tony Streef
 * @version 1.0 (maart 2014)
 */
public class Ball extends Actor
{
    private int deltaX;         // x movement speed
    private int deltaY;         // y movement speed
    private int count = 2;
    private Ball ball;
    
    private boolean stuck = true;   // stuck to paddle
    
    /**
     * Act. Move if we're not stuck.
     */
    public void act() 
    {
        if (!stuck) 
        {
            move();
            makeSmoke();
            if(((Board) getWorld()).endScreen())
            {
                verticalBounce();
            }
            else
            {
                checkOut();
            }
        }
    }
    
    /**
     * Move the ball. Then check what we've hit.
     */
    public void move()
    {
        setLocation (getX() + deltaX, getY() + deltaY);
        checkWalls();
        checkPaddle();
        checkBrick();
        checkBonus();
                   
    }
    
    /**
     * Check whether we've hit one of the three walls. Reverse direction if necessary.
     */
    public void checkWalls()
    {
        if (getX() == 0 || getX() == getWorld().getWidth()-1) {
            deltaX = -deltaX;
        }
        if (getY() == 0) {
            deltaY = -deltaY;
        }
    }
    
    /**
     * Check whether we're out (bottom of screen).
     */
    public void checkOut()
    {
        Actor trap = getOneIntersectingObject(Trap.class);
        if (getY() == getWorld().getHeight()-1 || trap != null) 
        {
            ((Board) getWorld()).ballIsOut();
            getWorld().removeObject(this);
        }
    }
    
    /**
     * De methode verticalBounce() zorgt ervoor dat de Minion (ball) in het rond blijft stuiteren. 
     */
    public void verticalBounce()
    {
        if (getY() == 0) 
        {
            deltaY = 7;
            deltaX = Greenfoot.getRandomNumber(20) - 10;
        }
        if (getY() == getWorld().getHeight()-1)
        {
            deltaY = -7;
            deltaX = Greenfoot.getRandomNumber(20) - 10;
        }
    }
    
    public void checkPaddle()
    {
        Actor paddle = getOneIntersectingObject(Paddle.class);
        if (paddle != null) {
            deltaY = -deltaY;
            int offset = getX() - paddle.getX();
            deltaX = deltaX + (offset/10);
                if (deltaX > 7) {
                    deltaX = 7;
                }
                    if (deltaX < -7) {
                        deltaX = -7;
                    }
            Greenfoot.playSound("Yahoo.wav");
        }            
    }
    
    /**
     * De methode checkBrick() controleert of de Minion(ball) botst tegen een banaan(brick).
     * Als dat het geval is wordt de banaan(brick) verwijdert, de score verhoogt, stuiterd de Minion(ball) weer weg.
     * Ook begint de Minion(ball) het woordje BANANA te zingen.
     */
    public void checkBrick()
    {
        Actor brick = getOneIntersectingObject(Brick.class);
        if (brick !=null)
        {
            deltaY = -deltaY;
            int offset = getX() - brick.getX();
            deltaX = deltaX + (offset/10);
                if (deltaX > 7) {
                    deltaX = 7;
                }
                    if (deltaX < -7) {
                        deltaX = -7;
                    }
                        
            ((Board)getWorld()).removeObject(brick);
            ((Board)getWorld()).incrementScore();
            Greenfoot.playSound("Babanana.mp3");
        }
    }
    
    /**
     * De methode checkBonus() controleert of de Minion(ball) botst tegen een tros bananen(bonus).
     * Als dat het geval is stuitert de Minion(ball) weer weg.
     * Vervolgens wordt de methode ballHitsBonus() uit de klasse Board uitgevoerd.
     */
    public void checkBonus()
    {
        Actor bonus = getOneIntersectingObject(Bonus.class);
        if (bonus !=null)
        {
            deltaY = -deltaY;
            int offset = getX() - bonus.getX();
            deltaX = deltaX + (offset/10);
                if (deltaX > 7) {
                    deltaX = 7;
                }
                    if (deltaX < -7) {
                        deltaX = -7;
                    }
            ((Board) getWorld()).ballHitsBonus();            
          
        }
    }
    
    /**
     * Move the ball a given distance sideways.
     */
    public void move(int dist)
    {
        setLocation (getX() + dist, getY());
    }

    /**
     * Put out a puff of smoke (only on every second call).
     */
    public void makeSmoke()
    {
        count--;
        if (count == 0) {
            getWorld().addObject ( new Smoke(), getX(), getY());
            count = 2;
        }
    }
    
    /**
     * Release the ball from the paddle.
     */
    public void release()
    {
        deltaX = Greenfoot.getRandomNumber(11) - 5;
        deltaY = -5;
        stuck = false;
        Greenfoot.playSound("Yahoo.wav");      
    }
    
    /**
     * De methode incrementSpeed() verandert de snelheid van de Minion(ball). 
     */
    public void incrementSpeed()
    {
        deltaX = deltaX - 2;
        deltaY = deltaY - 2;
    }
  
}