import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * De paddle is een trapoline in dit spel. 
 * De Minion(ball) springt gedurende het spel op deze trampoline(paddle)
 * De trampoline(paddle) kan met het toetsenbord gestuurd worden naar links en rechts om de Minion(ball) op te vangen.
 * Door te drukken op spatie begint een Minion(ball) met springen.
 * 
 * @author Tony Streef
 * @version 1.0 (maart 2014)
 */
public class Paddle extends Actor
{
    private Ball myBall;  // used before ball gets released
    public int numBall = 1; // Geeft het nummer van de Minion(ball). Begint standaard op 1.
    
    /**
     * When the paddle gets created, create a ball as well.
     */
    public void addedToWorld(World world)
    {
        newBall();
    }
    
    /**
     * Act - do whatever the Paddle wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        /**
         * Als de linkerpijl ingedrukt is, beweegt de pallet 9 pixels naar links.
         * Als de rechterpijl ingedrukt wordt, beweegt de pallet 9 pixels naart rechts.
         */
        if (Greenfoot.isKeyDown ("left")) 
        {
            move(-9);
        }
        if (Greenfoot.isKeyDown ("right")) 
        {
            move(9);
        }
        if (haveBall() && Greenfoot.isKeyDown ("space")) {
            ((Board)this.getWorld()).removeMessage4();
            releaseBall();
        }
        
    }
    
    public void move(int dist)
    {
        setLocation (getX() + dist, getY());
        if (myBall != null) 
        {
            myBall.move (dist);
        }
    }
    
    public void newBall()
    {
        myBall = new Ball();
        getWorld().addObject (myBall, getX(), getY()-20);
        numBall ++;
    }
        
    public boolean haveBall()
    {
        return myBall != null;
    }
        
    public void releaseBall()
    {
        myBall.release();
        myBall = null;
    }
        
    public int getNumBalls()
    {
        return numBall;
    }
    
    /**
     * De methode reduceNumBalls() verlaagt numBall met 1. Dit is nodig voor de extra levens.
     */
    public void reduceNumBalls()
    {
        numBall = numBall -1;
    }
    
    /**
     * De methode removeBall() verwijdert de Minion(ball) op de trampoline(paddle).  
     */
    public void removeBall()
    {
        getWorld().removeObject(myBall);
    }
}
